@@ -2,7 +2,6 @@
 # -*- coding: utf-8 -*-
 
 import errno
-import re
 import sys
 
 from subprocess    import call
@@ -19,7 +18,7 @@ from ACE_utils     import apply_blacklist
 from ACE_settings  import ACESettings
 from ACE_encoding  import ACEEncodingDecodeException
 
-version = '0.0.9'
+version = '0.0.10'
 
 langLookup = {
     3: QString.fromUtf8('English (United Kingdom)'),
@@ -394,8 +393,6 @@ class ACEMainWindow(ACEViewWindow): #{{{1
             
         self._dict.write()
 
-        call(['/usr/bin/killall', 'hildon-input-method'])
-
         if self.maemo:
             from PyQt4.QtMaemo5 import QMaemo5InformationBox
             QMaemo5InformationBox.information(self, 'Dictionary saved', QMaemo5InformationBox.DefaultTimeout)
